==> react-bootstrap-0.2.0.tgz: package/es/components/Loader/index.js <==
var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

import Spinner from '../Spinner';

var Loader = (_temp2 = _class = function (_Component) {
  _inherits(Loader, _Component);

  function Loader() {
    var _temp, _this, _ret;

    _classCallCheck(this, Loader);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      loading: _this.props.load,
      error: false
    }, _this.isUnmounted = false, _this.handleLoad = function (onLoad, onLoaded) {
      return _this.beforeLoading().then(function () {
        return !_this.isUnmounted && onLoad();
      }).then(function (res) {
        return !_this.isUnmounted && _this.afterLoading(res);
      }).then(function (res) {
        return !_this.isUnmounted && onLoaded(res);
      }).catch(function (error) {
        if (!_this.isUnmounted) {
          _this.setState({ loading: false, error: error });
        }

        throw error;
      });
    }, _this.beforeLoading = function () {
      return new Promise(function (resolve) {
        return _this.setState({ loading: true, error: false }, resolve);
      });
    }, _this.afterLoading = function (res) {
      return new Promise(function (resolve) {
        return _this.setState({ loading: false }, function () {
          return resolve(res);
        });
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Loader.prototype.componentWillMount = function componentWillMount() {
    if (this.props.load) {
      this.handleLoad(this.props.onLoad, this.props.onLoaded);
    }
  };

  Loader.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (!this.state.loading && nextProps.reload) {
      this.handleLoad(nextProps.onLoad, nextProps.onLoaded);
    }
  };

  Loader.prototype.componentWillUnmount = function componentWillUnmount() {
    this.isUnmounted = true;
  };

  Loader.prototype.render = function render() {
    var _props = this.props,
        loadingIndicator = _props.loadingIndicator,
        children = _props.children;
    var _state = this.state,
        loading = _state.loading,
        error = _state.error;


    if (error) {
      return React.createElement(
        'div',
        { className: 'alert alert-danger mb-0', role: 'alert' },
        React.createElement(
          'samp',
          null,
          String(error)
        )
      );
    }

    if (!loading) {
      return children;
    }

    return loadingIndicator;
  };

  return Loader;
}(Component), _class.defaultProps = {
  onLoad: function onLoad() {},
  onLoaded: function onLoaded() {},
  load: true,
  reload: false,
  loadingIndicator: React.createElement(Spinner, null),
  children: null
}, _temp2);
Loader.propTypes = process.env.NODE_ENV !== "production" ? {
  onLoad: PropTypes.func,
  onLoaded: PropTypes.func,
  load: PropTypes.bool,
  reload: PropTypes.bool,
  loadingIndicator: PropTypes.node,
  children: PropTypes.node
} : {};


export default Loader;

==> react-bootstrap-0.4.2.tgz: package/es/components/Loader/index.js <==
var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

import Spinner from '../Spinner';

var Loader = (_temp2 = _class = function (_Component) {
  _inherits(Loader, _Component);

  function Loader() {
    var _temp, _this, _ret;

    _classCallCheck(this, Loader);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      loading: _this.props.load,
      error: false
    }, _this.isUnmounted = false, _this.load = function () {
      return _this.beforeLoading().then(function () {
        return !_this.isUnmounted && _this.props.onLoad();
      }).then(function (res) {
        return !_this.isUnmounted && _this.afterLoading(res);
      }).then(function (res) {
        return !_this.isUnmounted && _this.props.onLoaded(res);
      }).catch(function (error) {
        if (!_this.isUnmounted) {
          _this.setState({ loading: false, error: error });
        }

        throw error;
      });
    }, _this.beforeLoading = function () {
      return new Promise(function (resolve) {
        return _this.setState({ loading: true, error: false }, resolve);
      });
    }, _this.afterLoading = function (res) {
      return new Promise(function (resolve) {
        return _this.setState({ loading: false }, function () {
          return resolve(res);
        });
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Loader.prototype.componentDidMount = function componentDidMount() {
    if (this.props.load) {
      this.load();
    }
  };

  Loader.prototype.componentDidUpdate = function componentDidUpdate() {
    if (!this.state.loading && this.props.reload) {
      this.load();
    }
  };

  Loader.prototype.componentWillUnmount = function componentWillUnmount() {
    this.isUnmounted = true;
  };

  Loader.prototype.render = function render() {
    var _props = this.props,
        loadingIndicator = _props.loadingIndicator,
        children = _props.children;
    var _state = this.state,
        loading = _state.loading,
        error = _state.error;


    if (error) {
      return React.createElement(
        'div',
        { className: 'alert alert-danger mb-0', role: 'alert' },
        React.createElement(
          'samp',
          null,
          String(error)
        )
      );
    }

    if (!loading) {
      return children;
    }

    return loadingIndicator;
  };

  return Loader;
}(Component), _class.defaultProps = {
  onLoad: function onLoad() {},
  onLoaded: function onLoaded() {},
  load: true,
  reload: false,
  loadingIndicator: React.createElement(Spinner, null),
  children: null
}, _temp2);
Loader.propTypes = process.env.NODE_ENV !== "production" ? {
  onLoad: PropTypes.func,
  onLoaded: PropTypes.func,
  load: PropTypes.bool,
  reload: PropTypes.bool,
  loadingIndicator: PropTypes.node,
  children: PropTypes.node
} : {};


export default Loader;
